<?php
/**
 * WidgetCode class file responsible for creating widget
 * @author Ahamed Rifaideen <rifajas@gmail.com>
 * @copyright (c) 2014, Ahamed Rifaideen
 */
class WidgetCode extends CCodeModel
{
    /**
     * @var string the widget class name
     */
    public $className;
    /**
     * @var string widget's base class
     */
    public $baseClass='CWidget';
    /**
     * @var string the widget description
     */
    public $description;
    /**
     * @var string list of public variables seperated by comma (,)
     */
    public $variables;
    /**
     * @var string list of public methods seperated by comma (,)
     */
    public $methods;
    /**
     * @var string the widget path alias
     */
    public $widgetPath='application.components';
    /**
     * @var boolean generate view based on this property
     */
    public $generateView;
    /**
     * @return array rules of WidgetCode
     */
    public function rules()
    {
        return array_merge(parent::rules(),array(
            array('className','required'),
            array('className','match','pattern'=>'/^\w+$/'),
            array('variables,methods,description','filter','filter'=>'trim'),
            array('baseClass,widgetPath','sticky'),
            array('generateView','boolean')
        ));
    }
    
    public function attributeLabels()
    {
        return array_merge(parent::attributeLabels(),array(
                'className' => 'Widget Name',
                'baseClass' => 'Base Class',
                'description' => 'Widget Description',
                'widgetPath' => 'Widget Path Alias',
                'variables' => 'Variables',
                'methods' => 'Methods'
        ));
    }
    
    public function prepare()
    {    
        $path = Yii::getPathOfAlias($this->widgetPath.'.'.$this->className).'.php';
        
        $code = $this->render($this->templatePath.'/widget.php');
        
        $this->files[] = new CCodeFile($path,$code);
        
        if($this->generateView)
        {   
            $path = Yii::getPathOfAlias($this->widgetPath.'.views.'.$this->viewName).'.php';
        
            $code = $this->render($this->templatePath.'/view.php');

            $this->files[] = new CCodeFile($path,$code);
        }
    }
    /**
     * view name to be generated
     * return lower case of class name
     * @return string
     */
    public function getViewName()
    {
        return strtolower($this->className);
    }
     
}